<?php

declare(strict_types=1);

namespace Drupal\joinup_community_content\Plugin\views\filter;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\state_machine\Plugin\views\filter\State;
use Drupal\state_machine\WorkflowManagerInterface;
use Drupal\state_machine_permissions\StateMachinePermissionsHelperInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Joinup content state.
 *
 * Workflow for nodes are calculated based on the associated group. We can not
 * use the standard approach because state filter does not use a real entity,
 * it does not have associated group, so workflows can not be defined.
 *
 * @see joinup_community_content_workflow_selector()
 */
class JoinupContentState extends State {

  public function __construct(
    array $configuration,
    string $plugin_id,
    mixed $plugin_definition,
    readonly EntityTypeManagerInterface $entity_type_manager,
    readonly EntityFieldManagerInterface $entity_field_manager,
    protected readonly WorkflowManagerInterface $workflowManager,
    protected readonly StateMachinePermissionsHelperInterface $stateMachinePermissionsHelper,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $entity_field_manager);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'),
      $container->get('plugin.manager.workflow'),
      $container->get('state_machine_permissions.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getWorkflows(EntityTypeInterface $entity_type, $field_name): array {
    if ($entity_type->id() !== 'node') {
      return parent::getWorkflows($entity_type, $field_name);
    }

    $workflows = [];
    foreach ($this->stateMachinePermissionsHelper->getPossibleWorkflowsForEntityType($entity_type->id()) as $definition) {
      $workflows[$definition['id']] = $this->workflowManager->createInstance($definition['id']);
    }

    return $workflows;
  }

}
