<?php

declare(strict_types=1);

namespace Drupal\joinup\Plugin\ArbitraryFacet;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\search_api_arbitrary_facet\Plugin\ArbitraryFacetBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides supports for facets generated by arbitrary queries.
 *
 * @ArbitraryFacet(
 *   id = "my_collections",
 *   label = @Translation("My collections"),
 * )
 */
class MyCollectionsArbitraryFacet extends ArbitraryFacetBase implements ContainerFactoryPluginInterface {

  public function __construct(
    array $configuration,
    string $plugin_id,
    mixed $plugin_definition,
    protected readonly AccountProxyInterface $currentUser,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFacetDefinition(): array {
    $definition = [
      'featured' => [
        'field_name' => 'site_featured',
        'field_condition' => 'true',
        'label' => $this->t('Featured collections'),
      ],
    ];

    if (!$this->currentUser->isAnonymous()) {
      $definition['mine'] = [
        'field_name' => 'entity_author',
        'field_condition' => $this->currentUser->id(),
        'label' => $this->t('My collections'),
      ];
    }

    return $definition;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    $contexts = parent::getCacheContexts();
    return Cache::mergeContexts(['collection_owner'], $contexts);
  }

}
